# setuptools-green #

This module provides a "green" command for setuptools scripts that uses
[green](https://github.com/CleanCut/green) to run tests.

By default, the verbose mode is used, but you can pass --quiet
to just show dots for passes and "E" for failures.
